/*
 * ===================================================================
 * RequirementsTableModel.java: Adapt a collection of requirements for
 *                              display in a JTable format.
 *
 * Written By: Mark Austin                                  March 2012
 * ===================================================================
 */

package adapter02;

import javax.swing.table.*;

public class RequirementsTableModel extends AbstractTableModel {

    protected Requirement[] requirements;
    protected String[] columnNames = new String[] { "Name", "Description", "Value" };

    // Construct a table of requirements from an array of requirements.

    public RequirementsTableModel( Requirement[] requirements ) {
        this.requirements = requirements;
    }

    // Return the number of columns in this table.

    public int getColumnCount() {
        return columnNames.length;
    }

    // Return the name of the indicated column.

    public String getColumnName(int i) {
        return columnNames[i];
    }

    // Return the number of rows in this table.

    public int getRowCount() {
        return requirements.length;
    }

    // Return the value at the indicated row and column..

    public Object getValueAt(int row, int col) {
        switch (col) {
        case 0:
             return requirements[row].getName();
        case 1:
             return requirements[row].getDescription();
        case 2:
             return new Double( requirements[row].getValue() );
        default:
             return null;
        }
    }
}
