/* 
 *  ==================================================================
 *  DisplayCompositePanel.java: A simple JPanel to display a graph ...
 *  ==================================================================
 */ 

package composite02;

import java.awt.*;
import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.geom.*;
import java.awt.Point;
import java.awt.event.*;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.beans.PropertyChangeEvent;
import java.util.*;
import java.util.List;
import java.util.Hashtable;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.Set;
import javax.swing.*;

public class DisplayCompositePanel extends JPanel {
  private CompositeHierarchy base;
  private AffineTransform      at;
  int iBorder = 10;
  int width, height;
  Graphics2D g2D;
  
  public DisplayCompositePanel( CompositeHierarchy base ) {
     this.base = base;
  }

  // Paint panel ...

  public void paint() {
     Graphics g = getGraphics();
     super.paintComponent(g);
     paintComponent(g);
  }
  
  protected void paintComponent(java.awt.Graphics g) {
     Dimension d = getSize();
     height = getSize().height;
     width  = getSize().width;
     g2D = (Graphics2D) g.create();
    
     // Draw vertices

     System.out.println("*** In DisplayCompositePanel(): draw vertices ....");

     // Draw edges for pair of vertices

     System.out.println("*** In DisplayCompositePanel(): draw edges ....");

     at = new AffineTransform();
     at.translate( iBorder, height - iBorder );
     at.scale( 1, -1 );
     g2D.setTransform( at );

     drawBorder();

     base.setAffineTransform( at );
     base.draw( g2D );
  }

  // Draw rectangle around exterior boundary ...

  protected void drawBorder() {
     int x1 = 0;
     int y1 = 0;
     int x2 = width - 2*iBorder;
     int y2 = height- 2*iBorder;

     g2D.setColor( Color.blue );
     g2D.draw( new Line2D.Double( x1, y1, x2, y1 ));
     g2D.draw( new Line2D.Double( x1, y1, x1, y2 ));
     g2D.draw( new Line2D.Double( x1, y2, x2, y2 ));
     g2D.draw( new Line2D.Double( x2, y1, x2, y2 ));
     g2D.setColor( Color.blue );
     g2D.fill(new Ellipse2D.Double( -5,  -5, 10, 10));
  }
}
