/*
 *  ====================================================================
 *  Light.java: Simple model of a light source.
 * 
 *  Modified by: Mark Austin                                   June 2012
 *  ====================================================================
*/

package observer03;

import java.util.*;

public class Light {
   private boolean on;   // on or off
   private List<LightListener> listeners = new ArrayList<LightListener>();

   // Light constructor ...
 
   public Light() {
      on = false;
      System.out.println("Light: constructed and off");
   }

   // Methods to add and remove listeners ...
 
   public void addLightListener(LightListener listener) {
      listeners.add(listener);
      System.out.printf("Light: Add LightWatcher %d\n",
                       ((LightWatcher) listener).id);
   }
 
   public void removeLightListener(LightListener listener) {
      listeners.remove(listener);
      System.out.printf("Light: Removed LightWatcher %d\n",
                       ((LightWatcher) listener).id);
   }

   // Methods to turn light on and off ....
 
   public void turnOn() {
      if (!on) {
         on = !on;
         System.out.println("Light: Turn on ... ");
         notifyListeners();
      }
   }
 
   public void turnOff() {
      if (on) {
         on = !on;
         System.out.println("Light: Turn off ... ");
         notifyListeners();
      }
   }

   // Notify watchers of the light ....
 
   private void notifyListeners() {
      LightEvent evt = new LightEvent(this);
      for (LightListener aListener : listeners) {
         if (on == true)
             aListener.lightTurnedOn(evt);
         else
             aListener.lightTurnedOff(evt);
      }
   }
}
