/*
 *  ============================================================================
 *  Node.java: A simple node with x,y coordinates and support for Node Listeners
 *  ============================================================================
 */

package observer04;

import java.util.*;

public class Node {
   private List<NodeListener> listeners = new ArrayList<NodeListener>();
   private double x, y;

   // Node constructors ...
 
   public Node() {}

   public Node( double x, double y ) {
      this.x = x; this.y = y;
   }

   // Methods to set and get nodal coordinates ..

   public void setX( double x ) {
      this.x = x;
   }

   public void setY( double y ) {
      this.y = y;
   }

   public double getX() { return x; }
   public double getY() { return y; }

   // String description of the node ...

   public String toString() {
      String s = "Node: (x,y) = ( " + x + "," + y + " )"; 
      return s;
   }

   // Support for node listeners ...
 
   public void addNodeListener( NodeListener listener) {
      listeners.add(listener);
   }
 
   public void removeNodeListener( NodeListener listener) {
      listeners.remove(listener);
   }

   // Move node a distance dx, dy, then notify all registered listeners.
 
   public void move( double dx, double dy ) {
      if ( dx != 0.0 || dy != 0.0 ) {
         System.out.println("Node moved: ... ");
         x = x + dx;
         y = y + dy;
         notifyListeners();
      }
   }
 
   private void notifyListeners() {
      NodeEvent evt = new NodeEvent(this);
      for (NodeListener aListener : listeners) {
           aListener.nodeMoved(evt);
      }
   }
}
