/*
 *  ======================================================================
 *  CompositePrintVisitor.java: Create print view of composite elements.
 *
 *  Written by: Mark Austin                                     June, 2012
 *  ======================================================================
 */

package visitor03.model;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Set;
import java.util.TreeMap;

import java.awt.geom.*;  // Needed for affine transformation....

import visitor03.model.*;
import visitor03.model.compound.*;
 
public class CompositePrintVisitor implements FeatureElementVisitor {
   private AffineTransform at;

   public void visit( Tree   tree ) {
      print ( (AbstractCompoundFeature) tree );
   }

   public void visit( CarModel car ) {
      print ( (AbstractCompoundFeature) car );
   }

   public void visit( HouseModel  house ) {
      print ( (AbstractCompoundFeature) house );
   }

   public void visit( AbstractFeature feature ) {}

   public void visit( CompositeHierarchy composite ) {}

   // Increment coordinate system at beginning of composite hieararchy.

   public void start( CompositeHierarchy composite ) {

      // Increment transformation parameters ...

      composite.transformationIncrement();

      this.at = composite.at;

      System.out.println("");
      System.out.println("Start Composite Hierarchy: " + composite.getName() );
      System.out.println("=================================================");
      System.out.printf( "Level = %2d\n", composite.getCurrentLevel() );
      System.out.println("-------------------------------------------------");
      System.out.println("");
   }

   // Decrement coordinate system at end of composite hieararchy.

   public void finish( CompositeHierarchy composite ) {

      System.out.println("");
      System.out.println("-------------------------------------------------");
      System.out.printf( "End level = %2d\n", composite.getCurrentLevel() );
      System.out.println("=================================================");

      composite.transformationDecrement();
   }

   // Decrment coordinate system at end of composite hieararchy.

   // Print details of a compound feature ...

   public void print( AbstractCompoundFeature af ) {

      // Print local and global coordinates of anchor point ....

      double flatmatrix[] = new double[6];
      CompositeHierarchy.at.getMatrix( flatmatrix );
      double dGlobalX = flatmatrix[0]*af.getX() + flatmatrix[2]*af.getY() + flatmatrix[4];
      double dGlobalY = flatmatrix[1]*af.getX() + flatmatrix[3]*af.getY() + flatmatrix[5];

      System.out.println("Compound Feature: " + af.getName() );
      System.out.println("----------------------------------" );
      System.out.printf( "Local  (x,y) = ( %5.1f, %5.1f )\n", af.getX(), af.getY() );
      System.out.printf( "Global (x,y) = ( %5.1f, %5.1f )\n", dGlobalX, dGlobalY );
      System.out.println( af.be.toString() );
      System.out.println("----------------------------------" );

      // Print feature items ordered by name ....

      TreeMap icopy = new TreeMap( af.items );
      Set st = icopy.keySet();
      Iterator itr = st.iterator();
      while (itr.hasNext()) {
         String key = (String) itr.next();
         Feature m = (Feature) icopy.get(key);
         System.out.println ( m.toString() );
      }

      System.out.println("-------------------------------" );
      System.out.println("" );
   }
}
