/** 
  *  ===============================================================
  *  Edge.java: Create edge objects for 2d modeling package ...
  *
  *  Constructor methods
  *
  *  -- public Edge();
  *
  *  Written by: Mark Austin                              June, 2012
  *  ===============================================================
  */ 

package visitor03.model.primitive;

import visitor03.model.*;

public class Edge extends AbstractFeature {
    double x1, y1, x2, y2;
    int     width;

    // Constructor method ....

    public Edge ( String sName, Point end1, Point end2 ) { 
       super();
       this.sName = sName;
       this.x1 = end1.getX();
       this.y1 = end1.getY();
       this.x2 = end2.getX();
       this.y2 = end2.getY();
       setX( (x1 + x2)/2.0 );
       setY( (y1 + y2)/2.0 );
       be.addPoint ( x1, y1 );
       be.addPoint ( x2, y2 );
    }

    // Retrieve parameter values ....

    public double getX1() {
       return x1;
    }

    public double getY1() {
       return y1;
    }

    public double getX2() {
       return x2;
    }

    public double getY2() {
       return y2;
    }

    public String getName() {
       return sName;
    }

    // Update edge coordinates ....

    public void update( Point end1, Point end2 ) { 
       this.x1 = end1.getX();
       this.y1 = end1.getY();
       this.x2 = end2.getX();
       this.y2 = end2.getY();
       setX( (x1 + x2)/2.0 );
       setY( (y1 + y2)/2.0 );
       be.setToNull();
       be.addPoint ( x1, y1 );
       be.addPoint ( x2, y2 );
    }

    // Create clone (i.e., deep copy) of Edge object ...

    public Edge clone() {
       try {
           Edge cloned = (Edge) super.clone();
           return cloned;
       } catch ( CloneNotSupportedException e) {
           System.out.println("*** Error in Edge.clone() ... ");
           return null;
       }
    }

    // Create string representation for edge object ....

    public String toString() {
        StringBuffer sb = new StringBuffer(1024);
        sb.append("Edge: (x1, y1) = (" + x1 + ", " + y1 + ") (x2, y2) = (" + x2 + ", " + y2 + ") ");
        sb.append("width = " + width );
        return sb.toString();
    }
}
